@@ -37,6 +37,9 @@ class UnknownProject(Exception):
 class UnknownRepository(Exception):
     pass
 
+class NotClonedRepository(Exception):
+    pass
+
 
 INFO=-1
 ERROR = 0
@@ -465,7 +468,22 @@ class Projects :
         for repo in sorted(project.repositories):
             self.pretty_print_repo(repo)
             printed_repos.add(repo)
-    
+
+            
+    def raise_exception_if_missing_repo(self,project_name):
+        
+        repos = self.get_repos(project_name)
+        missing = set()
+        for repo_name in repos:
+            cloned = self.already_cloned(repo_name)
+            if not cloned:
+                missing.add(repo_name)
+        if missing:
+            if len(missing)==1:
+                raise NotClonedRepository("missing repository: {}".format(list(missing)[0]))
+            else:
+                str_ = ", ".join(list(missing))
+                raise NotClonedRepository("missing repositories: {}".format(str_))
             
     def get_cloned_repos(self):
 
